@@ -137,10 +137,7 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         report_struct.peer = span.peer
         report_struct.is_error = span.error_occurred
         report_struct.tags = self.convert_tags(span.tags)
-        # logs 为空，统一不上报数据
-        logs = self.convert_logs(span.logs)
-        if logs:
-            report_struct.logs = self.convert_logs(span.logs)
+        report_struct.logs = self.convert_logs(span.logs)
         item = ReportStruct.convert(report_struct)
         functions.log("report_struct: %r", item, level=2)
         data = json.dumps(item).encode("utf-8")
