@@ -35,7 +35,7 @@ def install():
         if log_level.get(config.log_level) <= level:
             context = get_context()
             with context.new_exit_span(op="Log", peer="") as span:
-                span.layer = Layer.Unknown
+                span.layer = Layer.Local
                 span.component = ComponentType.Log
 
                 data = params_tostring(msg, level)
